```
Usage: vcd network external list-direct-org-vdc-network [OPTIONS] <name>

Options:
  --filter <name==org-vdc-net*>  filter for org vDC network
  -h, --help                     Show this message and exit.

```
